pecos.qeclib.steane.gates\_sq.paulis
====================================

.. automodule:: pecos.qeclib.steane.gates_sq.paulis











   .. rubric:: Classes

   .. autosummary::

      X
      Y
      Z
